% This Source Code Form is subject to the terms of the Mozilla Public

% License, v. 2.0. If a copy of the MPL was not distributed with this

% file, You can obtain one at http://mozilla.org/MPL/2.0/.

# Architectural Decision Records

We record major architectural decisions in Architecture Decision Records (ADRs),
as [described by Michael Nygard](http://thinkrelevance.com/blog/2011/11/15/documenting-architecture-decisions).
Below is the list of our current ADRs.

```{toctree}
:glob: true
:maxdepth: 1

decisions/*
```
